pub enum MapBody {
Node(String),
Subgraph(Box<Graph>),
}Expand description
Variants
Node(String)
Map each element through an existing node in this document, by id.
Subgraph(Box<Graph>)
Map each element through an embedded sub-graph. Boxed because a Graph
contains nodes, one of which may be a map, so the type is recursive.